Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(21)

Unified Diff: sync/internal_api/base_node.cc

Issue 1942593002: [Sync] Do not check IS_DIR bit on nigori node (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sync/internal_api/base_node.cc
diff --git a/sync/internal_api/base_node.cc b/sync/internal_api/base_node.cc
index 29d4574fffce394072b2bb7032313ad3324994b3..d7c6380aaf11cd3bf73301b563948a90a11b809c 100644
--- a/sync/internal_api/base_node.cc
+++ b/sync/internal_api/base_node.cc
@@ -163,8 +163,9 @@ bool BaseNode::GetIsFolder() const {
bool BaseNode::GetIsPermanentFolder() const {
bool is_permanent_folder = !GetEntry()->GetUniqueServerTag().empty();
if (is_permanent_folder) {
- // If the node is a permanent folder it must also have IS_DIR bit set.
- DCHECK(GetIsFolder());
+ // If the node is a permanent folder it must also have IS_DIR bit set,
+ // except some nigori nodes on old accounts.
+ DCHECK(GetIsFolder() || GetModelType() == NIGORI);
}
return is_permanent_folder;
}
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698